==> iaxmodem_1.1.0~dfsg.orig.tar.gz: iaxmodem-1.1.0/lib/spandsp/src/v22bis_rx_2400_fixed_rrc.h <==
#define PULSESHAPER_2400_GAIN        32767.000000f
#define PULSESHAPER_2400_COEFF_SETS  12
static const complexi16_t pulseshaper_2400[PULSESHAPER_2400_COEFF_SETS][37] =
{
    {
        {       0,        0},     /* Filter 0 */
        {    -106,       77},
        {     -62,     -191},
        {     257,        0},
        {     -89,      275},
        {    -229,     -166},
        {     183,     -133},
        {      34,      106},
        {      65,        0},
        {     -94,      292},
        {    -490,     -356},
        {     768,     -558},
        {     409,     1259},
        {   -1705,        0},
        {     640,    -1971},
        {    1943,     1411},
        {   -2160,     1569},
        {    -884,    -2721},
        {    2960,        0},
        {    -914,     2815},
        {   -2314,    -1681},
        {    2160,    -1569},
        {     742,     2284},
        {   -2072,        0},
        {     527,    -1622},
        {    1071,      778},
        {    -768,      558},
        {    -187,     -576},
        {     307,        0},
        {     -20,       62},
        {      90,       66},
        {    -183,      133},
        {     -87,     -269},
        {     289,        0},
        {     -79,      245},
        {    -162,     -118},
        {     106,      -77}
    },
    {
        {       0,        0},     /* Filter 1 */
        {    -111,       81},
        {     -63,     -196},
        {     261,        0},
        {     -89,      276},
        {    -227,     -164},
        {     177,     -129},
        {      30,       95},
        {      83,        0},
        {    -102,      314},
        {    -512,     -372},
        {     793,     -576},
        {     418,     1289},
        {   -1737,        0},
        {     649,    -1999},
        {    1963,     1426},
        {   -2176,     1581},
        {    -887,    -2732},
        {    2964,        0},
        {    -913,     2811},
        {   -2304,    -1674},
        {    2144,    -1558},
        {     734,     2260},
        {   -2043,        0},
        {     517,    -1592},
        {    1045,      759},
        {    -744,      541},
        {    -179,     -550},
        {     284,        0},
        {     -15,       46},
        {     100,       73},
        {    -189,      137},
        {     -88,     -271},
        {     288,        0},
        {     -78,      241},
        {    -158,     -114},
        {     102,      -74}
    },
    {
        {       0,        0},     /* Filter 2 */
        {    -116,       84},
        {     -65,     -201},
        {     265,        0},
        {     -90,      277},
        {    -224,     -163},
        {     171,     -124},
        {      26,       82},
        {     101,        0},
        {    -109,      336},
        {    -534,     -388},
        {     818,     -594},
        {     428,     1319},
        {   -1768,        0},
        {     658,    -2026},
        {    1983,     1440},
        {   -2191,     1592},
        {    -891,    -2743},
        {    2967,        0},
        {    -911,     2806},
        {   -2294,    -1666},
        {    2128,    -1546},
        {     726,     2235},
        {   -2013,        0},
        {     507,    -1561},
        {    1019,      740},
        {    -720,      523},
        {    -170,     -525},
        {     262,        0},
        {      -9,       30},
        {     109,       79},
        {    -194,      141},
        {     -88,     -273},
        {     286,        0},
        {     -77,      237},
        {    -153,     -111},
        {      97,      -70}
    },
    {
        {       0,        0},     /* Filter 3 */
        {    -121,       88},
        {     -66,     -206},
        {     268,        0},
        {     -90,      277},
        {    -221,     -161},
        {     165,     -120},
        {      22,       70},
        {     120,        0},
        {    -116,      358},
        {    -557,     -404},
        {     842,     -612},
        {     438,     1349},
        {   -1799,        0},
        {     667,    -2053},
        {    2002,     1455},
        {   -2205,     1602},
        {    -894,    -2753},
        {    2969,        0},
        {    -909,     2800},
        {   -2283,    -1658},
        {    2111,    -1534},
        {     718,     2210},
        {   -1983,        0},
        {     497,    -1531},
        {     994,      722},
        {    -696,      506},
        {    -162,     -500},
        {     241,        0},
        {      -4,       14},
        {     118,       86},
        {    -199,      144},
        {     -89,     -274},
        {     284,        0},
        {     -75,      233},
        {    -149,     -108},
        {      92,      -67}
    },
    {
        {       0,        0},     /* Filter 4 */
        {    -125,       91},
        {     -68,     -210},
        {     271,        0},
        {     -90,      278},
        {    -218,     -159},
        {     158,     -115},
        {      18,       57},
        {     139,        0},
        {    -123,      381},
        {    -579,     -421},
        {     867,     -630},
        {     448,     1380},
        {   -1830,        0},
        {     676,    -2080},
        {    2021,     1468},
        {   -2219,     1612},
        {    -897,    -2762},
        {    2971,        0},
        {    -907,     2794},
        {   -2271,    -1650},
        {    2094,    -1521},
        {     710,     2185},
        {   -1953,        0},
        {     487,    -1501},
        {     968,      703},
        {    -672,      488},
        {    -154,     -476},
        {     220,        0},
        {       0,        0},
        {     127,       92},
        {    -203,      148},
        {     -89,     -276},
        {     282,        0},
        {     -74,      229},
        {    -144,     -105},
        {      87,      -63}
    },
    {
        {       0,        0},     /* Filter 5 */
        {    -130,       94},
        {     -70,     -215},
        {     274,        0},
        {     -90,      277},
        {    -215,     -156},
        {     151,     -109},
        {      14,       43},
        {     159,        0},
        {    -131,      404},
        {    -602,     -437},
        {     892,     -648},
        {     458,     1410},
        {   -1861,        0},
        {     684,    -2107},
        {    2040,     1482},
        {   -2233,     1622},
        {    -900,    -2771},
        {    2972,        0},
        {    -905,     2787},
        {   -2259,    -1641},
        {    2077,    -1509},
        {     701,     2159},
        {   -1923,        0},
        {     478,    -1471},
        {     943,      685},
        {    -649,      471},
        {    -146,     -452},
        {     199,        0},
        {       5,      -15},
        {     135,       98},
        {    -208,      151},
        {     -90,     -277},
        {     280,        0},
        {     -73,      224},
        {    -139,     -101},
        {      83,      -60}
    },
    {
        {       0,        0},     /* Filter 6 */
        {    -135,       98},
        {     -71,     -220},
        {     277,        0},
        {     -90,      277},
        {    -212,     -154},
        {     143,     -104},
        {       9,       29},
        {     178,        0},
        {    -139,      428},
        {    -625,     -454},
        {     918,     -667},
        {     468,     1440},
        {   -1892,        0},
        {     693,    -2133},
        {    2059,     1495},
        {   -2246,     1632},
        {    -903,    -2779},
        {    2972,        0},
        {    -903,     2779},
        {   -2246,    -1632},
        {    2059,    -1495},
        {     693,     2133},
        {   -1892,        0},
        {     468,    -1440},
        {     918,      667},
        {    -625,      454},
        {    -139,     -428},
        {     178,        0},
        {       9,      -29},
        {     143,      104},
        {    -212,      154},
        {     -90,     -277},
        {     277,        0},
        {     -71,      220},
        {    -135,      -98},
        {      78,      -57}
    },
    {
        {       0,        0},     /* Filter 7 */
        {    -139,      101},
        {     -73,     -224},
        {     280,        0},
        {     -90,      277},
        {    -208,     -151},
        {     135,      -98},
        {       5,       15},
        {     199,        0},
        {    -146,      452},
        {    -649,     -471},
        {     943,     -685},
        {     478,     1471},
        {   -1923,        0},
        {     701,    -2159},
        {    2077,     1509},
        {   -2259,     1641},
        {    -905,    -2787},
        {    2972,        0},
        {    -900,     2771},
        {   -2233,    -1622},
        {    2040,    -1482},
        {     684,     2107},
        {   -1861,        0},
        {     458,    -1410},
        {     892,      648},
        {    -602,      437},
        {    -131,     -404},
        {     159,        0},
        {      14,      -43},
        {     151,      109},
        {    -215,      156},
        {     -90,     -277},
        {     274,        0},
        {     -70,      215},
        {    -130,      -94},
        {      73,      -53}
    },
    {
        {       0,        0},     /* Filter 8 */
        {    -144,      105},
        {     -74,     -229},
        {     282,        0},
        {     -89,      276},
        {    -203,     -148},
        {     127,      -92},
        {       0,        0},
        {     220,        0},
        {    -154,      476},
        {    -672,     -488},
        {     968,     -703},
        {     487,     1501},
        {   -1953,        0},
        {     710,    -2185},
        {    2094,     1521},
        {   -2271,     1650},
        {    -907,    -2794},
        {    2971,        0},
        {    -897,     2762},
        {   -2219,    -1612},
        {    2021,    -1468},
        {     676,     2080},
        {   -1830,        0},
        {     448,    -1380},
        {     867,      630},
        {    -579,      421},
        {    -123,     -381},
        {     139,        0},
        {      18,      -57},
        {     158,      115},
        {    -218,      159},
        {     -90,     -278},
        {     271,        0},
        {     -68,      210},
        {    -125,      -91},
        {      69,      -50}
    },
    {
        {       0,        0},     /* Filter 9 */
        {    -149,      108},
        {     -75,     -233},
        {     284,        0},
        {     -89,      274},
        {    -199,     -144},
        {     118,      -86},
        {      -4,      -14},
        {     241,        0},
        {    -162,      500},
        {    -696,     -506},
        {     994,     -722},
        {     497,     1531},
        {   -1983,        0},
        {     718,    -2210},
        {    2111,     1534},
        {   -2283,     1658},
        {    -909,    -2800},
        {    2969,        0},
        {    -894,     2753},
        {   -2205,    -1602},
        {    2002,    -1455},
        {     667,     2053},
        {   -1799,        0},
        {     438,    -1349},
        {     842,      612},
        {    -557,      404},
        {    -116,     -358},
        {     120,        0},
        {      22,      -70},
        {     165,      120},
        {    -221,      161},
        {     -90,     -277},
        {     268,        0},
        {     -66,      206},
        {    -121,      -88},
        {      64,      -46}
    },
    {
        {       0,        0},     /* Filter 10 */
        {    -153,      111},
        {     -77,     -237},
        {     286,        0},
        {     -88,      273},
        {    -194,     -141},
        {     109,      -79},
        {      -9,      -30},
        {     262,        0},
        {    -170,      525},
        {    -720,     -523},
        {    1019,     -740},
        {     507,     1561},
        {   -2013,        0},
        {     726,    -2235},
        {    2128,     1546},
        {   -2294,     1666},
        {    -911,    -2806},
        {    2967,        0},
        {    -891,     2743},
        {   -2191,    -1592},
        {    1983,    -1440},
        {     658,     2026},
        {   -1768,        0},
        {     428,    -1319},
        {     818,      594},
        {    -534,      388},
        {    -109,     -336},
        {     101,        0},
        {      26,      -82},
        {     171,      124},
        {    -224,      163},
        {     -90,     -277},
        {     265,        0},
        {     -65,      201},
        {    -116,      -84},
        {      59,      -43}
    },
    {
        {       0,        0},     /* Filter 11 */
        {    -158,      114},
        {     -78,     -241},
        {     288,        0},
        {     -88,      271},
        {    -189,     -137},
        {     100,      -73},
        {     -15,      -46},
        {     284,        0},
        {    -179,      550},
        {    -744,     -541},
        {    1045,     -759},
        {     517,     1592},
        {   -2043,        0},
        {     734,    -2260},
        {    2144,     1558},
        {   -2304,     1674},
        {    -913,    -2811},
        {    2964,        0},
        {    -887,     2732},
        {   -2176,    -1581},
        {    1963,    -1426},
        {     649,     1999},
        {   -1737,        0},
        {     418,    -1289},
        {     793,      576},
        {    -512,      372},
        {    -102,     -314},
        {      83,        0},
        {      30,      -95},
        {     177,      129},
        {    -227,      164},
        {     -89,     -276},
        {     261,        0},
        {     -63,      196},
        {    -111,      -81},
        {      55,      -40}
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v22bis_rx_2400_fixed_rrc.h <==
#define RX_PULSESHAPER_2400_GAIN        32767.000000f
#define RX_PULSESHAPER_2400_COEFF_SETS  12
static const complexi16_t rx_pulseshaper_2400[RX_PULSESHAPER_2400_COEFF_SETS][37] =
{
    {
        {       0,        0},     /* Filter 0 */
        {    -106,       77},
        {     -62,     -191},
        {     257,        0},
        {     -89,      275},
        {    -229,     -166},
        {     183,     -133},
        {      34,      106},
        {      65,        0},
        {     -94,      292},
        {    -490,     -356},
        {     768,     -558},
        {     409,     1259},
        {   -1705,        0},
        {     640,    -1971},
        {    1943,     1411},
        {   -2160,     1569},
        {    -884,    -2721},
        {    2960,        0},
        {    -914,     2815},
        {   -2314,    -1681},
        {    2160,    -1569},
        {     742,     2284},
        {   -2072,        0},
        {     527,    -1622},
        {    1071,      778},
        {    -768,      558},
        {    -187,     -576},
        {     307,        0},
        {     -20,       62},
        {      90,       66},
        {    -183,      133},
        {     -87,     -269},
        {     289,        0},
        {     -79,      245},
        {    -162,     -118},
        {     106,      -77}
    },
    {
        {       0,        0},     /* Filter 1 */
        {    -111,       81},
        {     -63,     -196},
        {     261,        0},
        {     -89,      276},
        {    -227,     -164},
        {     177,     -129},
        {      30,       95},
        {      83,        0},
        {    -102,      314},
        {    -512,     -372},
        {     793,     -576},
        {     418,     1289},
        {   -1737,        0},
        {     649,    -1999},
        {    1963,     1426},
        {   -2176,     1581},
        {    -887,    -2732},
        {    2964,        0},
        {    -913,     2811},
        {   -2304,    -1674},
        {    2144,    -1558},
        {     734,     2260},
        {   -2043,        0},
        {     517,    -1592},
        {    1045,      759},
        {    -744,      541},
        {    -179,     -550},
        {     284,        0},
        {     -15,       46},
        {     100,       73},
        {    -189,      137},
        {     -88,     -271},
        {     288,        0},
        {     -78,      241},
        {    -158,     -114},
        {     102,      -74}
    },
    {
        {       0,        0},     /* Filter 2 */
        {    -116,       84},
        {     -65,     -201},
        {     265,        0},
        {     -90,      277},
        {    -224,     -163},
        {     171,     -124},
        {      26,       82},
        {     101,        0},
        {    -109,      336},
        {    -534,     -388},
        {     818,     -594},
        {     428,     1319},
        {   -1768,        0},
        {     658,    -2026},
        {    1983,     1440},
        {   -2191,     1592},
        {    -891,    -2743},
        {    2967,        0},
        {    -911,     2806},
        {   -2294,    -1666},
        {    2128,    -1546},
        {     726,     2235},
        {   -2013,        0},
        {     507,    -1561},
        {    1019,      740},
        {    -720,      523},
        {    -170,     -525},
        {     262,        0},
        {      -9,       30},
        {     109,       79},
        {    -194,      141},
        {     -88,     -273},
        {     286,        0},
        {     -77,      237},
        {    -153,     -111},
        {      97,      -70}
    },
    {
        {       0,        0},     /* Filter 3 */
        {    -121,       88},
        {     -66,     -206},
        {     268,        0},
        {     -90,      277},
        {    -221,     -161},
        {     165,     -120},
        {      22,       70},
        {     120,        0},
        {    -116,      358},
        {    -557,     -404},
        {     842,     -612},
        {     438,     1349},
        {   -1799,        0},
        {     667,    -2053},
        {    2002,     1455},
        {   -2205,     1602},
        {    -894,    -2753},
        {    2969,        0},
        {    -909,     2800},
        {   -2283,    -1658},
        {    2111,    -1534},
        {     718,     2210},
        {   -1983,        0},
        {     497,    -1531},
        {     994,      722},
        {    -696,      506},
        {    -162,     -500},
        {     241,        0},
        {      -4,       14},
        {     118,       86},
        {    -199,      144},
        {     -89,     -274},
        {     284,        0},
        {     -75,      233},
        {    -149,     -108},
        {      92,      -67}
    },
    {
        {       0,        0},     /* Filter 4 */
        {    -125,       91},
        {     -68,     -210},
        {     271,        0},
        {     -90,      278},
        {    -218,     -159},
        {     158,     -115},
        {      18,       57},
        {     139,        0},
        {    -123,      381},
        {    -579,     -421},
        {     867,     -630},
        {     448,     1380},
        {   -1830,        0},
        {     676,    -2080},
        {    2021,     1468},
        {   -2219,     1612},
        {    -897,    -2762},
        {    2971,        0},
        {    -907,     2794},
        {   -2271,    -1650},
        {    2094,    -1521},
        {     710,     2185},
        {   -1953,        0},
        {     487,    -1501},
        {     968,      703},
        {    -672,      488},
        {    -154,     -476},
        {     220,        0},
        {       0,        0},
        {     127,       92},
        {    -203,      148},
        {     -89,     -276},
        {     282,        0},
        {     -74,      229},
        {    -144,     -105},
        {      87,      -63}
    },
    {
        {       0,        0},     /* Filter 5 */
        {    -130,       94},
        {     -70,     -215},
        {     274,        0},
        {     -90,      277},
        {    -215,     -156},
        {     151,     -109},
        {      14,       43},
        {     159,        0},
        {    -131,      404},
        {    -602,     -437},
        {     892,     -648},
        {     458,     1410},
        {   -1861,        0},
        {     684,    -2107},
        {    2040,     1482},
        {   -2233,     1622},
        {    -900,    -2771},
        {    2972,        0},
        {    -905,     2787},
        {   -2259,    -1641},
        {    2077,    -1509},
        {     701,     2159},
        {   -1923,        0},
        {     478,    -1471},
        {     943,      685},
        {    -649,      471},
        {    -146,     -452},
        {     199,        0},
        {       5,      -15},
        {     135,       98},
        {    -208,      151},
        {     -90,     -277},
        {     280,        0},
        {     -73,      224},
        {    -139,     -101},
        {      83,      -60}
    },
    {
        {       0,        0},     /* Filter 6 */
        {    -135,       98},
        {     -71,     -220},
        {     277,        0},
        {     -90,      277},
        {    -212,     -154},
        {     143,     -104},
        {       9,       29},
        {     178,        0},
        {    -139,      428},
        {    -625,     -454},
        {     918,     -667},
        {     468,     1440},
        {   -1892,        0},
        {     693,    -2133},
        {    2059,     1495},
        {   -2246,     1632},
        {    -903,    -2779},
        {    2972,        0},
        {    -903,     2779},
        {   -2246,    -1632},
        {    2059,    -1495},
        {     693,     2133},
        {   -1892,        0},
        {     468,    -1440},
        {     918,      667},
        {    -625,      454},
        {    -139,     -428},
        {     178,        0},
        {       9,      -29},
        {     143,      104},
        {    -212,      154},
        {     -90,     -277},
        {     277,        0},
        {     -71,      220},
        {    -135,      -98},
        {      78,      -57}
    },
    {
        {       0,        0},     /* Filter 7 */
        {    -139,      101},
        {     -73,     -224},
        {     280,        0},
        {     -90,      277},
        {    -208,     -151},
        {     135,      -98},
        {       5,       15},
        {     199,        0},
        {    -146,      452},
        {    -649,     -471},
        {     943,     -685},
        {     478,     1471},
        {   -1923,        0},
        {     701,    -2159},
        {    2077,     1509},
        {   -2259,     1641},
        {    -905,    -2787},
        {    2972,        0},
        {    -900,     2771},
        {   -2233,    -1622},
        {    2040,    -1482},
        {     684,     2107},
        {   -1861,        0},
        {     458,    -1410},
        {     892,      648},
        {    -602,      437},
        {    -131,     -404},
        {     159,        0},
        {      14,      -43},
        {     151,      109},
        {    -215,      156},
        {     -90,     -277},
        {     274,        0},
        {     -70,      215},
        {    -130,      -94},
        {      73,      -53}
    },
    {
        {       0,        0},     /* Filter 8 */
        {    -144,      105},
        {     -74,     -229},
        {     282,        0},
        {     -89,      276},
        {    -203,     -148},
        {     127,      -92},
        {       0,        0},
        {     220,        0},
        {    -154,      476},
        {    -672,     -488},
        {     968,     -703},
        {     487,     1501},
        {   -1953,        0},
        {     710,    -2185},
        {    2094,     1521},
        {   -2271,     1650},
        {    -907,    -2794},
        {    2971,        0},
        {    -897,     2762},
        {   -2219,    -1612},
        {    2021,    -1468},
        {     676,     2080},
        {   -1830,        0},
        {     448,    -1380},
        {     867,      630},
        {    -579,      421},
        {    -123,     -381},
        {     139,        0},
        {      18,      -57},
        {     158,      115},
        {    -218,      159},
        {     -90,     -278},
        {     271,        0},
        {     -68,      210},
        {    -125,      -91},
        {      69,      -50}
    },
    {
        {       0,        0},     /* Filter 9 */
        {    -149,      108},
        {     -75,     -233},
        {     284,        0},
        {     -89,      274},
        {    -199,     -144},
        {     118,      -86},
        {      -4,      -14},
        {     241,        0},
        {    -162,      500},
        {    -696,     -506},
        {     994,     -722},
        {     497,     1531},
        {   -1983,        0},
        {     718,    -2210},
        {    2111,     1534},
        {   -2283,     1658},
        {    -909,    -2800},
        {    2969,        0},
        {    -894,     2753},
        {   -2205,    -1602},
        {    2002,    -1455},
        {     667,     2053},
        {   -1799,        0},
        {     438,    -1349},
        {     842,      612},
        {    -557,      404},
        {    -116,     -358},
        {     120,        0},
        {      22,      -70},
        {     165,      120},
        {    -221,      161},
        {     -90,     -277},
        {     268,        0},
        {     -66,      206},
        {    -121,      -88},
        {      64,      -46}
    },
    {
        {       0,        0},     /* Filter 10 */
        {    -153,      111},
        {     -77,     -237},
        {     286,        0},
        {     -88,      273},
        {    -194,     -141},
        {     109,      -79},
        {      -9,      -30},
        {     262,        0},
        {    -170,      525},
        {    -720,     -523},
        {    1019,     -740},
        {     507,     1561},
        {   -2013,        0},
        {     726,    -2235},
        {    2128,     1546},
        {   -2294,     1666},
        {    -911,    -2806},
        {    2967,        0},
        {    -891,     2743},
        {   -2191,    -1592},
        {    1983,    -1440},
        {     658,     2026},
        {   -1768,        0},
        {     428,    -1319},
        {     818,      594},
        {    -534,      388},
        {    -109,     -336},
        {     101,        0},
        {      26,      -82},
        {     171,      124},
        {    -224,      163},
        {     -90,     -277},
        {     265,        0},
        {     -65,      201},
        {    -116,      -84},
        {      59,      -43}
    },
    {
        {       0,        0},     /* Filter 11 */
        {    -158,      114},
        {     -78,     -241},
        {     288,        0},
        {     -88,      271},
        {    -189,     -137},
        {     100,      -73},
        {     -15,      -46},
        {     284,        0},
        {    -179,      550},
        {    -744,     -541},
        {    1045,     -759},
        {     517,     1592},
        {   -2043,        0},
        {     734,    -2260},
        {    2144,     1558},
        {   -2304,     1674},
        {    -913,    -2811},
        {    2964,        0},
        {    -887,     2732},
        {   -2176,    -1581},
        {    1963,    -1426},
        {     649,     1999},
        {   -1737,        0},
        {     418,    -1289},
        {     793,      576},
        {    -512,      372},
        {    -102,     -314},
        {      83,        0},
        {      30,      -95},
        {     177,      129},
        {    -227,      164},
        {     -89,     -276},
        {     261,        0},
        {     -63,      196},
        {    -111,      -81},
        {      55,      -40}
    }
};
